(window.webpackJsonp=window.webpackJsonp||[]).push([[147],{279:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({fields:{year:{displayName:"کال",relative:{0:"سږکال",1:"بل کال","-1":"پروسږکال"},relativeTime:{future:{one:"په {0} کال کے",other:"په {0} کالونو کے"},past:{one:"{0} کال مخکے",other:"{0} کاله مخکے"}}},"year-short":{displayName:"کال",relative:{0:"سږکال",1:"بل کال","-1":"پروسږکال"},relativeTime:{future:{one:"په {0} کال کے",other:"په {0} کالونو کے"},past:{one:"{0} کال مخکے",other:"{0} کاله مخکے"}}},"year-narrow":{displayName:"کال",relative:{0:"سږکال",1:"بل کال","-1":"پروسږکال"},relativeTime:{future:{one:"په {0} کال کے",other:"په {0} کالونو کے"},past:{one:"{0} کال مخکے",other:"{0} کاله مخکے"}}}},locale:"ps-PK"},{fields:{year:{displayName:"کال",relative:{0:"سږکال",1:"بل کال","-1":"پروسږکال"},relativeTime:{future:{one:"په {0} کال کې",other:"په {0} کالونو کې"},past:{one:"{0} کال مخکې",other:"{0} کاله مخکې"}}},"year-short":{displayName:"کال",relative:{0:"سږکال",1:"بل کال","-1":"پروسږکال"},relativeTime:{future:{one:"په {0} کال کې",other:"په {0} کالونو کې"},past:{one:"{0} کال مخکې",other:"{0} کاله مخکې"}}},"year-narrow":{displayName:"کال",relative:{0:"سږکال",1:"بل کال","-1":"پروسږکال"},relativeTime:{future:{one:"په {0} کال کې",other:"په {0} کالونو کې"},past:{one:"{0} کال مخکې",other:"{0} کاله مخکې"}}},quarter:{displayName:"Quarter",relative:{0:"this quarter",1:"next quarter","-1":"last quarter"},relativeTime:{future:{other:"+{0} Q"},past:{other:"-{0} Q"}}},"quarter-short":{displayName:"Quarter",relative:{0:"this quarter",1:"next quarter","-1":"last quarter"},relativeTime:{future:{other:"+{0} Q"},past:{other:"-{0} Q"}}},"quarter-narrow":{displayName:"Quarter",relative:{0:"this quarter",1:"next quarter","-1":"last quarter"},relativeTime:{future:{other:"+{0} Q"},past:{other:"-{0} Q"}}},month:{displayName:"مياشت",relative:{0:"this month",1:"next month","-1":"last month"},relativeTime:{future:{other:"+{0} m"},past:{other:"-{0} m"}}},"month-short":{displayName:"مياشت",relative:{0:"this month",1:"next month","-1":"last month"},relativeTime:{future:{other:"+{0} m"},past:{other:"-{0} m"}}},"month-narrow":{displayName:"مياشت",relative:{0:"this month",1:"next month","-1":"last month"},relativeTime:{future:{other:"+{0} m"},past:{other:"-{0} m"}}},week:{displayName:"اونۍ",relative:{0:"this week",1:"next week","-1":"last week"},relativeTime:{future:{other:"+{0} w"},past:{other:"-{0} w"}}},"week-short":{displayName:"اونۍ",relative:{0:"this week",1:"next week","-1":"last week"},relativeTime:{future:{other:"+{0} w"},past:{other:"-{0} w"}}},"week-narrow":{displayName:"اونۍ",relative:{0:"this week",1:"next week","-1":"last week"},relativeTime:{future:{other:"+{0} w"},past:{other:"-{0} w"}}},day:{displayName:"ورځ",relative:{0:"today",1:"tomorrow","-1":"yesterday"},relativeTime:{future:{other:"+{0} d"},past:{other:"-{0} d"}}},"day-short":{displayName:"ورځ",relative:{0:"today",1:"tomorrow","-1":"yesterday"},relativeTime:{future:{other:"+{0} d"},past:{other:"-{0} d"}}},"day-narrow":{displayName:"ورځ",relative:{0:"today",1:"tomorrow","-1":"yesterday"},relativeTime:{future:{other:"+{0} d"},past:{other:"-{0} d"}}},hour:{displayName:"ساعت",relative:{0:"this hour"},relativeTime:{future:{other:"+{0} h"},past:{other:"-{0} h"}}},"hour-short":{displayName:"ساعت",relative:{0:"this hour"},relativeTime:{future:{other:"+{0} h"},past:{other:"-{0} h"}}},"hour-narrow":{displayName:"ساعت",relative:{0:"this hour"},relativeTime:{future:{other:"+{0} h"},past:{other:"-{0} h"}}},minute:{displayName:"دقيقه",relative:{0:"this minute"},relativeTime:{future:{other:"+{0} min"},past:{other:"-{0} min"}}},"minute-short":{displayName:"دقيقه",relative:{0:"this minute"},relativeTime:{future:{other:"+{0} min"},past:{other:"-{0} min"}}},"minute-narrow":{displayName:"دقيقه",relative:{0:"this minute"},relativeTime:{future:{other:"+{0} min"},past:{other:"-{0} min"}}},second:{displayName:"ثانيه",relative:{0:"now"},relativeTime:{future:{other:"+{0} s"},past:{other:"-{0} s"}}},"second-short":{displayName:"ثانيه",relative:{0:"now"},relativeTime:{future:{other:"+{0} s"},past:{other:"-{0} s"}}},"second-narrow":{displayName:"ثانيه",relative:{0:"now"},relativeTime:{future:{other:"+{0} s"},past:{other:"-{0} s"}}}},locale:"ps"})}}]);
//# sourceMappingURL=147.9b87f5664ebf50104bfb.index.js.map