(window.webpackJsonp=window.webpackJsonp||[]).push([[51],{183:function(e,a){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({fields:{year:{displayName:"ár",relative:{0:"í ár",1:"næsta ár","-1":"í fjør"},relativeTime:{future:{one:"um {0} ár",other:"um {0} ár"},past:{one:"{0} ár síðan",other:"{0} ár síðan"}}},"year-short":{displayName:"ár",relative:{0:"í ár",1:"næsta ár","-1":"í fjør"},relativeTime:{future:{one:"um {0} ár",other:"um {0} ár"},past:{one:"{0} ár síðan",other:"{0} ár síðan"}}},"year-narrow":{displayName:"ár",relative:{0:"í ár",1:"næsta ár","-1":"í fjør"},relativeTime:{future:{one:"um {0} ár",other:"um {0} ár"},past:{one:"{0} ár síðan",other:"{0} ár síðan"}}},quarter:{displayName:"ársfjórðingur",relative:{0:"hendan ársfjórðingin",1:"næsta ársfjórðing","-1":"seinasta ársfjórðing"},relativeTime:{future:{one:"um {0} ársfjórðing",other:"um {0} ársfjórðingar"},past:{one:"{0} ársfjórðing síðan",other:"{0} ársfjórðingar síðan"}}},"quarter-short":{displayName:"ársfj.",relative:{0:"hendan ársfjórðingin",1:"næsta ársfjórðing","-1":"seinasta ársfjórðing"},relativeTime:{future:{one:"um {0} ársfj.",other:"um {0} ársfj."},past:{one:"{0} ársfj. síðan",other:"{0} ársfj. síðan"}}},"quarter-narrow":{displayName:"ársfj.",relative:{0:"hendan ársfjórðingin",1:"næsta ársfjórðing","-1":"seinasta ársfjórðing"},relativeTime:{future:{one:"um {0} ársfj.",other:"um {0} ársfj."},past:{one:"{0} ársfj. síðan",other:"{0} ársfj. síðan"}}},month:{displayName:"mánaður",relative:{0:"henda mánaðin",1:"næsta mánað","-1":"seinasta mánað"},relativeTime:{future:{one:"um {0} mánað",other:"um {0} mánaðir"},past:{one:"{0} mánað síðan",other:"{0} mánaðir síðan"}}},"month-short":{displayName:"mnð.",relative:{0:"henda mánaðin",1:"næsta mánað","-1":"seinasta mánað"},relativeTime:{future:{one:"um {0} mnð.",other:"um {0} mnð."},past:{one:"{0} mnð. síðan",other:"{0} mnð. síðan"}}},"month-narrow":{displayName:"mnð.",relative:{0:"henda mánaðin",1:"næsta mánað","-1":"seinasta mánað"},relativeTime:{future:{one:"um {0} mnð.",other:"um {0} mnð."},past:{one:"{0} mnð. síðan",other:"{0} mnð. síðan"}}},week:{displayName:"vika",relative:{0:"hesu viku",1:"næstu viku","-1":"seinastu viku"},relativeTime:{future:{one:"um {0} viku",other:"um {0} vikur"},past:{one:"{0} vika síðan",other:"{0} vikur síðan"}}},"week-short":{displayName:"vi.",relative:{0:"hesu viku",1:"næstu viku","-1":"seinastu viku"},relativeTime:{future:{one:"um {0} vi.",other:"um {0} vi."},past:{one:"{0} vi. síðan",other:"{0} vi. síðan"}}},"week-narrow":{displayName:"v.",relative:{0:"hesu viku",1:"næstu viku","-1":"seinastu viku"},relativeTime:{future:{one:"um {0} v.",other:"um {0} v."},past:{one:"{0} v. síðan",other:"{0} v. síðan"}}},day:{displayName:"dagur",relative:{0:"í dag",1:"í morgin",2:"í ovurmorgin","-2":"fyrradagin","-1":"í gjár"},relativeTime:{future:{one:"um {0} dag",other:"um {0} dagar"},past:{one:"{0} dagur síðan",other:"{0} dagar síðan"}}},"day-short":{displayName:"da.",relative:{0:"í dag",1:"í morgin",2:"í ovurmorgin","-2":"fyrradagin","-1":"í gjár"},relativeTime:{future:{one:"um {0} da.",other:"um {0} da."},past:{one:"{0} da. síðan",other:"{0} da. síðan"}}},"day-narrow":{displayName:"d.",relative:{0:"í dag",1:"í morgin",2:"í ovurmorgin","-2":"fyrradagin","-1":"í gjár"},relativeTime:{future:{one:"um {0} d.",other:"um {0} d."},past:{one:"{0} d. síðan",other:"{0} d. síðan"}}},hour:{displayName:"tími",relative:{0:"hendan tíman"},relativeTime:{future:{one:"um {0} tíma",other:"um {0} tímar"},past:{one:"{0} tími síðan",other:"{0} tímar síðan"}}},"hour-short":{displayName:"t.",relative:{0:"hendan tíman"},relativeTime:{future:{one:"um {0} t.",other:"um {0} t."},past:{one:"{0} t. síðan",other:"{0} t. síðan"}}},"hour-narrow":{displayName:"t.",relative:{0:"hendan tíman"},relativeTime:{future:{one:"um {0} t.",other:"um {0} t."},past:{one:"{0} t. síðan",other:"{0} t. síðan"}}},minute:{displayName:"minuttur",relative:{0:"hendan minuttin"},relativeTime:{future:{one:"um {0} minutt",other:"um {0} minuttir"},past:{one:"{0} minutt síðan",other:"{0} minuttir síðan"}}},"minute-short":{displayName:"min.",relative:{0:"hendan minuttin"},relativeTime:{future:{one:"um {0} min.",other:"um {0} min."},past:{one:"{0} min. síðan",other:"{0} min. síðan"}}},"minute-narrow":{displayName:"m.",relative:{0:"hendan minuttin"},relativeTime:{future:{one:"um {0} m.",other:"um {0} m."},past:{one:"{0} m. síðan",other:"{0} m. síðan"}}},second:{displayName:"sekund",relative:{0:"nú"},relativeTime:{future:{one:"um {0} sekund",other:"um {0} sekund"},past:{one:"{0} sekund síðan",other:"{0} sekund síðan"}}},"second-short":{displayName:"sek.",relative:{0:"nú"},relativeTime:{future:{one:"um {0} sek.",other:"um {0} sek."},past:{one:"{0} sek. síðan",other:"{0} sek. síðan"}}},"second-narrow":{displayName:"s.",relative:{0:"nú"},relativeTime:{future:{one:"um {0} s.",other:"um {0} s."},past:{one:"{0} s. síðan",other:"{0} s. síðan"}}}},locale:"fo"})}}]);
//# sourceMappingURL=51.9b87f5664ebf50104bfb.index.js.map