(window.webpackJsonp=window.webpackJsonp||[]).push([[75],{207:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({fields:{year:{displayName:"anno",relative:{0:"quest’anno",1:"anno prossimo","-1":"anno scorso"},relativeTime:{future:{one:"tra {0} anno",other:"tra {0} anni"},past:{one:"{0} anno fa",other:"{0} anni fa"}}},"year-short":{displayName:"anno",relative:{0:"quest’anno",1:"anno prossimo","-1":"anno scorso"},relativeTime:{future:{one:"tra {0} anno",other:"tra {0} anni"},past:{one:"{0} anno fa",other:"{0} anni fa"}}},"year-narrow":{displayName:"anno",relative:{0:"quest’anno",1:"anno prossimo","-1":"anno scorso"},relativeTime:{future:{one:"tra {0} anno",other:"tra {0} anni"},past:{one:"{0} anno fa",other:"{0} anni fa"}}},quarter:{displayName:"trimestre",relative:{0:"questo trimestre",1:"trimestre prossimo","-1":"trimestre scorso"},relativeTime:{future:{one:"tra {0} trimestre",other:"tra {0} trimestri"},past:{one:"{0} trimestre fa",other:"{0} trimestri fa"}}},"quarter-short":{displayName:"trim.",relative:{0:"questo trim.",1:"trim. prossimo","-1":"trim. scorso"},relativeTime:{future:{one:"tra {0} trim.",other:"tra {0} trim."},past:{one:"{0} trim. fa",other:"{0} trim. fa"}}},"quarter-narrow":{displayName:"trim.",relative:{0:"questo trim.",1:"trim. prossimo","-1":"trim. scorso"},relativeTime:{future:{one:"tra {0} trim.",other:"tra {0} trim."},past:{one:"{0} trim. fa",other:"{0} trim. fa"}}},month:{displayName:"mese",relative:{0:"questo mese",1:"mese prossimo","-1":"mese scorso"},relativeTime:{future:{one:"tra {0} mese",other:"tra {0} mesi"},past:{one:"{0} mese fa",other:"{0} mesi fa"}}},"month-short":{displayName:"mese",relative:{0:"questo mese",1:"mese prossimo","-1":"mese scorso"},relativeTime:{future:{one:"tra {0} mese",other:"tra {0} mesi"},past:{one:"{0} mese fa",other:"{0} mesi fa"}}},"month-narrow":{displayName:"mese",relative:{0:"questo mese",1:"mese prossimo","-1":"mese scorso"},relativeTime:{future:{one:"tra {0} mese",other:"tra {0} mesi"},past:{one:"{0} mese fa",other:"{0} mesi fa"}}},week:{displayName:"settimana",relative:{0:"questa settimana",1:"settimana prossima","-1":"settimana scorsa"},relativeTime:{future:{one:"tra {0} settimana",other:"tra {0} settimane"},past:{one:"{0} settimana fa",other:"{0} settimane fa"}}},"week-short":{displayName:"sett.",relative:{0:"questa settimana",1:"settimana prossima","-1":"settimana scorsa"},relativeTime:{future:{one:"tra {0} sett.",other:"tra {0} sett."},past:{one:"{0} sett. fa",other:"{0} sett. fa"}}},"week-narrow":{displayName:"sett.",relative:{0:"questa settimana",1:"settimana prossima","-1":"settimana scorsa"},relativeTime:{future:{one:"tra {0} sett.",other:"tra {0} sett."},past:{one:"{0} sett. fa",other:"{0} sett. fa"}}},day:{displayName:"giorno",relative:{0:"oggi",1:"domani",2:"dopodomani","-2":"l’altro ieri","-1":"ieri"},relativeTime:{future:{one:"tra {0} giorno",other:"tra {0} giorni"},past:{one:"{0} giorno fa",other:"{0} giorni fa"}}},"day-short":{displayName:"g",relative:{0:"oggi",1:"domani",2:"dopodomani","-2":"l’altro ieri","-1":"ieri"},relativeTime:{future:{one:"tra {0} g",other:"tra {0} gg"},past:{one:"{0} g fa",other:"{0} gg fa"}}},"day-narrow":{displayName:"g",relative:{0:"oggi",1:"domani",2:"dopodomani","-2":"l’altro ieri","-1":"ieri"},relativeTime:{future:{one:"tra {0} g",other:"tra {0} gg"},past:{one:"{0} g fa",other:"{0} gg fa"}}},hour:{displayName:"ora",relative:{0:"quest’ora"},relativeTime:{future:{one:"tra {0} ora",other:"tra {0} ore"},past:{one:"{0} ora fa",other:"{0} ore fa"}}},"hour-short":{displayName:"h.",relative:{0:"quest’ora"},relativeTime:{future:{one:"tra {0} h",other:"tra {0} h"},past:{one:"{0} h fa",other:"{0} h fa"}}},"hour-narrow":{displayName:"h",relative:{0:"quest’ora"},relativeTime:{future:{one:"tra {0} h",other:"tra {0} h"},past:{one:"{0} h fa",other:"{0} h fa"}}},minute:{displayName:"minuto",relative:{0:"questo minuto"},relativeTime:{future:{one:"tra {0} minuto",other:"tra {0} minuti"},past:{one:"{0} minuto fa",other:"{0} minuti fa"}}},"minute-short":{displayName:"min",relative:{0:"questo minuto"},relativeTime:{future:{one:"tra {0} min",other:"tra {0} min"},past:{one:"{0} min fa",other:"{0} min fa"}}},"minute-narrow":{displayName:"min",relative:{0:"questo minuto"},relativeTime:{future:{one:"tra {0} min",other:"tra {0} min"},past:{one:"{0} min fa",other:"{0} min fa"}}},second:{displayName:"secondo",relative:{0:"ora"},relativeTime:{future:{one:"tra {0} secondo",other:"tra {0} secondi"},past:{one:"{0} secondo fa",other:"{0} secondi fa"}}},"second-short":{displayName:"s",relative:{0:"ora"},relativeTime:{future:{one:"tra {0} s",other:"tra {0} sec."},past:{one:"{0} s fa",other:"{0} sec. fa"}}},"second-narrow":{displayName:"s",relative:{0:"ora"},relativeTime:{future:{one:"tra {0} s",other:"tra {0} s"},past:{one:"{0} s fa",other:"{0} s fa"}}}},locale:"it"})}}]);
//# sourceMappingURL=75.9b87f5664ebf50104bfb.index.js.map