(window.webpackJsonp=window.webpackJsonp||[]).push([[185],{317:function(e,a){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({fields:{year:{displayName:"yıl",relative:{0:"bu yıl",1:"gelecek yıl","-1":"geçen yıl"},relativeTime:{future:{one:"{0} yıl sonra",other:"{0} yıl sonra"},past:{one:"{0} yıl önce",other:"{0} yıl önce"}}},"year-short":{displayName:"yıl",relative:{0:"bu yıl",1:"gelecek yıl","-1":"geçen yıl"},relativeTime:{future:{one:"{0} yıl sonra",other:"{0} yıl sonra"},past:{one:"{0} yıl önce",other:"{0} yıl önce"}}},"year-narrow":{displayName:"yıl",relative:{0:"bu yıl",1:"gelecek yıl","-1":"geçen yıl"},relativeTime:{future:{one:"{0} yıl sonra",other:"{0} yıl sonra"},past:{one:"{0} yıl önce",other:"{0} yıl önce"}}},quarter:{displayName:"çeyrek",relative:{0:"bu çeyrek",1:"gelecek çeyrek","-1":"geçen çeyrek"},relativeTime:{future:{one:"{0} çeyrek sonra",other:"{0} çeyrek sonra"},past:{one:"{0} çeyrek önce",other:"{0} çeyrek önce"}}},"quarter-short":{displayName:"çyr.",relative:{0:"bu çeyrek",1:"gelecek çeyrek","-1":"geçen çeyrek"},relativeTime:{future:{one:"{0} çyr. sonra",other:"{0} çyr. sonra"},past:{one:"{0} çyr. önce",other:"{0} çyr. önce"}}},"quarter-narrow":{displayName:"çyr.",relative:{0:"bu çeyrek",1:"gelecek çeyrek","-1":"geçen çeyrek"},relativeTime:{future:{one:"{0} çyr. sonra",other:"{0} çyr. sonra"},past:{one:"{0} çyr. önce",other:"{0} çyr. önce"}}},month:{displayName:"ay",relative:{0:"bu ay",1:"gelecek ay","-1":"geçen ay"},relativeTime:{future:{one:"{0} ay sonra",other:"{0} ay sonra"},past:{one:"{0} ay önce",other:"{0} ay önce"}}},"month-short":{displayName:"ay",relative:{0:"bu ay",1:"gelecek ay","-1":"geçen ay"},relativeTime:{future:{one:"{0} ay sonra",other:"{0} ay sonra"},past:{one:"{0} ay önce",other:"{0} ay önce"}}},"month-narrow":{displayName:"ay",relative:{0:"bu ay",1:"gelecek ay","-1":"geçen ay"},relativeTime:{future:{one:"{0} ay sonra",other:"{0} ay sonra"},past:{one:"{0} ay önce",other:"{0} ay önce"}}},week:{displayName:"hafta",relative:{0:"bu hafta",1:"gelecek hafta","-1":"geçen hafta"},relativeTime:{future:{one:"{0} hafta sonra",other:"{0} hafta sonra"},past:{one:"{0} hafta önce",other:"{0} hafta önce"}}},"week-short":{displayName:"hf.",relative:{0:"bu hafta",1:"gelecek hafta","-1":"geçen hafta"},relativeTime:{future:{one:"{0} hf. sonra",other:"{0} hf. sonra"},past:{one:"{0} hf. önce",other:"{0} hf. önce"}}},"week-narrow":{displayName:"hf.",relative:{0:"bu hafta",1:"gelecek hafta","-1":"geçen hafta"},relativeTime:{future:{one:"{0} hf. sonra",other:"{0} hf. sonra"},past:{one:"{0} hf. önce",other:"{0} hf. önce"}}},day:{displayName:"gün",relative:{0:"bugün",1:"yarın",2:"öbür gün","-2":"evvelsi gün","-1":"dün"},relativeTime:{future:{one:"{0} gün sonra",other:"{0} gün sonra"},past:{one:"{0} gün önce",other:"{0} gün önce"}}},"day-short":{displayName:"gün",relative:{0:"bugün",1:"yarın",2:"öbür gün","-2":"evvelsi gün","-1":"dün"},relativeTime:{future:{one:"{0} gün sonra",other:"{0} gün sonra"},past:{one:"{0} gün önce",other:"{0} gün önce"}}},"day-narrow":{displayName:"gün",relative:{0:"bugün",1:"yarın",2:"öbür gün","-2":"evvelsi gün","-1":"dün"},relativeTime:{future:{one:"{0} gün sonra",other:"{0} gün sonra"},past:{one:"{0} gün önce",other:"{0} gün önce"}}},hour:{displayName:"saat",relative:{0:"bu saat"},relativeTime:{future:{one:"{0} saat sonra",other:"{0} saat sonra"},past:{one:"{0} saat önce",other:"{0} saat önce"}}},"hour-short":{displayName:"sa.",relative:{0:"bu saat"},relativeTime:{future:{one:"{0} sa. sonra",other:"{0} sa. sonra"},past:{one:"{0} sa. önce",other:"{0} sa. önce"}}},"hour-narrow":{displayName:"sa.",relative:{0:"bu saat"},relativeTime:{future:{one:"{0} sa. sonra",other:"{0} sa. sonra"},past:{one:"{0} sa. önce",other:"{0} sa. önce"}}},minute:{displayName:"dakika",relative:{0:"bu dakika"},relativeTime:{future:{one:"{0} dakika sonra",other:"{0} dakika sonra"},past:{one:"{0} dakika önce",other:"{0} dakika önce"}}},"minute-short":{displayName:"dk.",relative:{0:"bu dakika"},relativeTime:{future:{one:"{0} dk. sonra",other:"{0} dk. sonra"},past:{one:"{0} dk. önce",other:"{0} dk. önce"}}},"minute-narrow":{displayName:"dk.",relative:{0:"bu dakika"},relativeTime:{future:{one:"{0} dk. sonra",other:"{0} dk. sonra"},past:{one:"{0} dk. önce",other:"{0} dk. önce"}}},second:{displayName:"saniye",relative:{0:"şimdi"},relativeTime:{future:{one:"{0} saniye sonra",other:"{0} saniye sonra"},past:{one:"{0} saniye önce",other:"{0} saniye önce"}}},"second-short":{displayName:"sn.",relative:{0:"şimdi"},relativeTime:{future:{one:"{0} sn. sonra",other:"{0} sn. sonra"},past:{one:"{0} sn. önce",other:"{0} sn. önce"}}},"second-narrow":{displayName:"sn.",relative:{0:"şimdi"},relativeTime:{future:{one:"{0} sn. sonra",other:"{0} sn. sonra"},past:{one:"{0} sn. önce",other:"{0} sn. önce"}}}},locale:"tr"})}}]);
//# sourceMappingURL=185.9b87f5664ebf50104bfb.index.js.map