(window.webpackJsonp=window.webpackJsonp||[]).push([[186],{318:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({fields:{year:{displayName:"ел",relative:{0:"this year",1:"next year","-1":"last year"},relativeTime:{future:{other:"+{0} y"},past:{other:"-{0} y"}}},"year-short":{displayName:"ел",relative:{0:"this year",1:"next year","-1":"last year"},relativeTime:{future:{other:"+{0} y"},past:{other:"-{0} y"}}},"year-narrow":{displayName:"ел",relative:{0:"this year",1:"next year","-1":"last year"},relativeTime:{future:{other:"+{0} y"},past:{other:"-{0} y"}}},quarter:{displayName:"квартал",relative:{0:"this quarter",1:"next quarter","-1":"last quarter"},relativeTime:{future:{other:"+{0} Q"},past:{other:"-{0} Q"}}},"quarter-short":{displayName:"кв.",relative:{0:"this quarter",1:"next quarter","-1":"last quarter"},relativeTime:{future:{other:"+{0} Q"},past:{other:"-{0} Q"}}},"quarter-narrow":{displayName:"кв.",relative:{0:"this quarter",1:"next quarter","-1":"last quarter"},relativeTime:{future:{other:"+{0} Q"},past:{other:"-{0} Q"}}},month:{displayName:"ай",relative:{0:"this month",1:"next month","-1":"last month"},relativeTime:{future:{other:"+{0} m"},past:{other:"-{0} m"}}},"month-short":{displayName:"ай",relative:{0:"this month",1:"next month","-1":"last month"},relativeTime:{future:{other:"+{0} m"},past:{other:"-{0} m"}}},"month-narrow":{displayName:"ай",relative:{0:"this month",1:"next month","-1":"last month"},relativeTime:{future:{other:"+{0} m"},past:{other:"-{0} m"}}},week:{displayName:"атна",relative:{0:"this week",1:"next week","-1":"last week"},relativeTime:{future:{other:"+{0} w"},past:{other:"-{0} w"}}},"week-short":{displayName:"атна",relative:{0:"this week",1:"next week","-1":"last week"},relativeTime:{future:{other:"+{0} w"},past:{other:"-{0} w"}}},"week-narrow":{displayName:"атна",relative:{0:"this week",1:"next week","-1":"last week"},relativeTime:{future:{other:"+{0} w"},past:{other:"-{0} w"}}},day:{displayName:"көн",relative:{0:"бүген",1:"иртәгә","-1":"кичә"},relativeTime:{future:{other:"+{0} d"},past:{other:"-{0} d"}}},"day-short":{displayName:"көн",relative:{0:"бүген",1:"иртәгә","-1":"кичә"},relativeTime:{future:{other:"+{0} d"},past:{other:"-{0} d"}}},"day-narrow":{displayName:"көн",relative:{0:"бүген",1:"иртәгә","-1":"кичә"},relativeTime:{future:{other:"+{0} d"},past:{other:"-{0} d"}}},hour:{displayName:"сәгать",relative:{0:"this hour"},relativeTime:{future:{other:"+{0} h"},past:{other:"-{0} h"}}},"hour-short":{displayName:"сәг.",relative:{0:"this hour"},relativeTime:{future:{other:"+{0} h"},past:{other:"-{0} h"}}},"hour-narrow":{displayName:"сәг.",relative:{0:"this hour"},relativeTime:{future:{other:"+{0} h"},past:{other:"-{0} h"}}},minute:{displayName:"минут",relative:{0:"this minute"},relativeTime:{future:{other:"+{0} min"},past:{other:"-{0} min"}}},"minute-short":{displayName:"мин.",relative:{0:"this minute"},relativeTime:{future:{other:"+{0} min"},past:{other:"-{0} min"}}},"minute-narrow":{displayName:"мин.",relative:{0:"this minute"},relativeTime:{future:{other:"+{0} min"},past:{other:"-{0} min"}}},second:{displayName:"секунд",relative:{0:"now"},relativeTime:{future:{other:"+{0} s"},past:{other:"-{0} s"}}},"second-short":{displayName:"с.",relative:{0:"now"},relativeTime:{future:{other:"+{0} s"},past:{other:"-{0} s"}}},"second-narrow":{displayName:"с.",relative:{0:"now"},relativeTime:{future:{other:"+{0} s"},past:{other:"-{0} s"}}}},locale:"tt"})}}]);
//# sourceMappingURL=186.9b87f5664ebf50104bfb.index.js.map