(window.webpackJsonp=window.webpackJsonp||[]).push([[178],{310:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({fields:{year:{displayName:"సంవత్సరం",relative:{0:"ఈ సంవత్సరం",1:"తదుపరి సంవత్సరం","-1":"గత సంవత్సరం"},relativeTime:{future:{one:"{0} సంవత్సరంలో",other:"{0} సంవత్సరాల్లో"},past:{one:"{0} సంవత్సరం క్రితం",other:"{0} సంవత్సరాల క్రితం"}}},"year-short":{displayName:"సం.",relative:{0:"ఈ సంవత్సరం",1:"తదుపరి సంవత్సరం","-1":"గత సంవత్సరం"},relativeTime:{future:{one:"{0} సం.లో",other:"{0} సం.ల్లో"},past:{one:"{0} సం. క్రితం",other:"{0} సం. క్రితం"}}},"year-narrow":{displayName:"సం.",relative:{0:"ఈ సంవత్సరం",1:"తదుపరి సంవత్సరం","-1":"గత సంవత్సరం"},relativeTime:{future:{one:"{0} సం.లో",other:"{0} సం.ల్లో"},past:{one:"{0} సం. క్రితం",other:"{0} సం. క్రితం"}}},quarter:{displayName:"త్రైమాసికం",relative:{0:"ఈ త్రైమాసికం",1:"తదుపరి త్రైమాసికం","-1":"గత త్రైమాసికం"},relativeTime:{future:{one:"{0} త్రైమాసికంలో",other:"{0} త్రైమాసికాల్లో"},past:{one:"{0} త్రైమాసికం క్రితం",other:"{0} త్రైమాసికాల క్రితం"}}},"quarter-short":{displayName:"త్రై.",relative:{0:"ఈ త్రైమాసికం",1:"తదుపరి త్రైమాసికం","-1":"గత త్రైమాసికం"},relativeTime:{future:{one:"{0} త్రైమా.లో",other:"{0} త్రైమా.ల్లో"},past:{one:"{0} త్రైమా. క్రితం",other:"{0} త్రైమా. క్రితం"}}},"quarter-narrow":{displayName:"త్రై.",relative:{0:"ఈ త్రైమాసికం",1:"తదుపరి త్రైమాసికం","-1":"గత త్రైమాసికం"},relativeTime:{future:{one:"{0} త్రైమాసికంలో",other:"{0} త్రైమాసికాల్లో"},past:{one:"{0} త్రైమా. క్రితం",other:"{0} త్రైమా. క్రితం"}}},month:{displayName:"నెల",relative:{0:"ఈ నెల",1:"తదుపరి నెల","-1":"గత నెల"},relativeTime:{future:{one:"{0} నెలలో",other:"{0} నెలల్లో"},past:{one:"{0} నెల క్రితం",other:"{0} నెలల క్రితం"}}},"month-short":{displayName:"నెల",relative:{0:"ఈ నెల",1:"తదుపరి నెల","-1":"గత నెల"},relativeTime:{future:{one:"{0} నెలలో",other:"{0} నెలల్లో"},past:{one:"{0} నెల క్రితం",other:"{0} నెలల క్రితం"}}},"month-narrow":{displayName:"నె",relative:{0:"ఈ నెల",1:"తదుపరి నెల","-1":"గత నెల"},relativeTime:{future:{one:"{0} నెలలో",other:"{0} నెలల్లో"},past:{one:"{0} నెల క్రితం",other:"{0} నెలల క్రితం"}}},week:{displayName:"వారము",relative:{0:"ఈ వారం",1:"తదుపరి వారం","-1":"గత వారం"},relativeTime:{future:{one:"{0} వారంలో",other:"{0} వారాల్లో"},past:{one:"{0} వారం క్రితం",other:"{0} వారాల క్రితం"}}},"week-short":{displayName:"వా",relative:{0:"ఈ వారం",1:"తదుపరి వారం","-1":"గత వారం"},relativeTime:{future:{one:"{0} వారంలో",other:"{0} వారాల్లో"},past:{one:"{0} వారం క్రితం",other:"{0} వారాల క్రితం"}}},"week-narrow":{displayName:"వా",relative:{0:"ఈ వారం",1:"తదుపరి వారం","-1":"గత వారం"},relativeTime:{future:{one:"{0} వారంలో",other:"{0} వారాల్లో"},past:{one:"{0} వారం క్రితం",other:"{0} వారాల క్రితం"}}},day:{displayName:"దినం",relative:{0:"ఈ రోజు",1:"రేపు",2:"ఎల్లుండి","-2":"మొన్న","-1":"నిన్న"},relativeTime:{future:{one:"{0} రోజులో",other:"{0} రోజుల్లో"},past:{one:"{0} రోజు క్రితం",other:"{0} రోజుల క్రితం"}}},"day-short":{displayName:"దినం",relative:{0:"ఈ రోజు",1:"రేపు",2:"ఎల్లుండి","-2":"మొన్న","-1":"నిన్న"},relativeTime:{future:{one:"{0} రోజులో",other:"{0} రోజుల్లో"},past:{one:"{0} రోజు క్రితం",other:"{0} రోజుల క్రితం"}}},"day-narrow":{displayName:"రోజు",relative:{0:"ఈ రోజు",1:"రేపు",2:"ఎల్లుండి","-2":"మొన్న","-1":"నిన్న"},relativeTime:{future:{one:"{0} రోజులో",other:"{0} రోజుల్లో"},past:{one:"{0} రోజు క్రితం",other:"{0} రోజుల క్రితం"}}},hour:{displayName:"గంట",relative:{0:"ఈ గంట"},relativeTime:{future:{one:"{0} గంటలో",other:"{0} గంటల్లో"},past:{one:"{0} గంట క్రితం",other:"{0} గంటల క్రితం"}}},"hour-short":{displayName:"గం.",relative:{0:"ఈ గంట"},relativeTime:{future:{one:"{0} గం.లో",other:"{0} గం.లో"},past:{one:"{0} గం. క్రితం",other:"{0} గం. క్రితం"}}},"hour-narrow":{displayName:"గం",relative:{0:"ఈ గంట"},relativeTime:{future:{one:"{0} గం.లో",other:"{0} గం.లో"},past:{one:"{0} గం. క్రితం",other:"{0} గం. క్రితం"}}},minute:{displayName:"నిమిషము",relative:{0:"ఈ నిమిషం"},relativeTime:{future:{one:"{0} నిమిషంలో",other:"{0} నిమిషాల్లో"},past:{one:"{0} నిమిషం క్రితం",other:"{0} నిమిషాల క్రితం"}}},"minute-short":{displayName:"నిమి.",relative:{0:"ఈ నిమిషం"},relativeTime:{future:{one:"{0} నిమి.లో",other:"{0} నిమి.లో"},past:{one:"{0} నిమి. క్రితం",other:"{0} నిమి. క్రితం"}}},"minute-narrow":{displayName:"ని",relative:{0:"ఈ నిమిషం"},relativeTime:{future:{one:"{0} నిమి.లో",other:"{0} నిమి.లో"},past:{one:"{0} నిమి. క్రితం",other:"{0} నిమి. క్రితం"}}},second:{displayName:"సెకను",relative:{0:"ప్రస్తుతం"},relativeTime:{future:{one:"{0} సెకనులో",other:"{0} సెకన్లలో"},past:{one:"{0} సెకను క్రితం",other:"{0} సెకన్ల క్రితం"}}},"second-short":{displayName:"సెక.",relative:{0:"ప్రస్తుతం"},relativeTime:{future:{one:"{0} సెకనులో",other:"{0} సెకన్లలో"},past:{one:"{0} సెక. క్రితం",other:"{0} సెక. క్రితం"}}},"second-narrow":{displayName:"సెక.",relative:{0:"ప్రస్తుతం"},relativeTime:{future:{one:"{0} సెక.లో",other:"{0} సెక. లో"},past:{one:"{0} సెక. క్రితం",other:"{0} సెక. క్రితం"}}}},locale:"te"})}}]);
//# sourceMappingURL=178.9b87f5664ebf50104bfb.index.js.map