(window.webpackJsonp=window.webpackJsonp||[]).push([[97],{229:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({fields:{year:{displayName:"Bǝk",relative:{0:"this year",1:"next year","-1":"last year"},relativeTime:{future:{other:"+{0} y"},past:{other:"-{0} y"}}},"year-short":{displayName:"Bǝk",relative:{0:"this year",1:"next year","-1":"last year"},relativeTime:{future:{other:"+{0} y"},past:{other:"-{0} y"}}},"year-narrow":{displayName:"Bǝk",relative:{0:"this year",1:"next year","-1":"last year"},relativeTime:{future:{other:"+{0} y"},past:{other:"-{0} y"}}},quarter:{displayName:"Quarter",relative:{0:"this quarter",1:"next quarter","-1":"last quarter"},relativeTime:{future:{other:"+{0} Q"},past:{other:"-{0} Q"}}},"quarter-short":{displayName:"Quarter",relative:{0:"this quarter",1:"next quarter","-1":"last quarter"},relativeTime:{future:{other:"+{0} Q"},past:{other:"-{0} Q"}}},"quarter-narrow":{displayName:"Quarter",relative:{0:"this quarter",1:"next quarter","-1":"last quarter"},relativeTime:{future:{other:"+{0} Q"},past:{other:"-{0} Q"}}},month:{displayName:"Ŋwíí",relative:{0:"this month",1:"next month","-1":"last month"},relativeTime:{future:{other:"+{0} m"},past:{other:"-{0} m"}}},"month-short":{displayName:"Ŋwíí",relative:{0:"this month",1:"next month","-1":"last month"},relativeTime:{future:{other:"+{0} m"},past:{other:"-{0} m"}}},"month-narrow":{displayName:"Ŋwíí",relative:{0:"this month",1:"next month","-1":"last month"},relativeTime:{future:{other:"+{0} m"},past:{other:"-{0} m"}}},week:{displayName:"Sɔ́ndǝ",relative:{0:"this week",1:"next week","-1":"last week"},relativeTime:{future:{other:"+{0} w"},past:{other:"-{0} w"}}},"week-short":{displayName:"Sɔ́ndǝ",relative:{0:"this week",1:"next week","-1":"last week"},relativeTime:{future:{other:"+{0} w"},past:{other:"-{0} w"}}},"week-narrow":{displayName:"Sɔ́ndǝ",relative:{0:"this week",1:"next week","-1":"last week"},relativeTime:{future:{other:"+{0} w"},past:{other:"-{0} w"}}},day:{displayName:"Ŋwós",relative:{0:"Gɛ́ɛnǝ",1:"Ridúrǝ́","-1":"Rinkɔɔ́"},relativeTime:{future:{other:"+{0} d"},past:{other:"-{0} d"}}},"day-short":{displayName:"Ŋwós",relative:{0:"Gɛ́ɛnǝ",1:"Ridúrǝ́","-1":"Rinkɔɔ́"},relativeTime:{future:{other:"+{0} d"},past:{other:"-{0} d"}}},"day-narrow":{displayName:"Ŋwós",relative:{0:"Gɛ́ɛnǝ",1:"Ridúrǝ́","-1":"Rinkɔɔ́"},relativeTime:{future:{other:"+{0} d"},past:{other:"-{0} d"}}},hour:{displayName:"Cámɛɛn",relative:{0:"this hour"},relativeTime:{future:{other:"+{0} h"},past:{other:"-{0} h"}}},"hour-short":{displayName:"Cámɛɛn",relative:{0:"this hour"},relativeTime:{future:{other:"+{0} h"},past:{other:"-{0} h"}}},"hour-narrow":{displayName:"Cámɛɛn",relative:{0:"this hour"},relativeTime:{future:{other:"+{0} h"},past:{other:"-{0} h"}}},minute:{displayName:"Mǝnít",relative:{0:"this minute"},relativeTime:{future:{other:"+{0} min"},past:{other:"-{0} min"}}},"minute-short":{displayName:"Mǝnít",relative:{0:"this minute"},relativeTime:{future:{other:"+{0} min"},past:{other:"-{0} min"}}},"minute-narrow":{displayName:"Mǝnít",relative:{0:"this minute"},relativeTime:{future:{other:"+{0} min"},past:{other:"-{0} min"}}},second:{displayName:"Háu",relative:{0:"now"},relativeTime:{future:{other:"+{0} s"},past:{other:"-{0} s"}}},"second-short":{displayName:"Háu",relative:{0:"now"},relativeTime:{future:{other:"+{0} s"},past:{other:"-{0} s"}}},"second-narrow":{displayName:"Háu",relative:{0:"now"},relativeTime:{future:{other:"+{0} s"},past:{other:"-{0} s"}}}},locale:"ksf"})}}]);
//# sourceMappingURL=97.9b87f5664ebf50104bfb.index.js.map